@@ -238,7 +238,7 @@ def _get_unit_vector(vector):
 
 
 def _get_signed_angle_between(v1, v2, radians=False):
-    """Returns the interior angle between vectors v1 and v2.
+    """Returns the signed angle between vectors v1 and v2.
 
     Parameters
     ----------
@@ -681,3 +681,10 @@ def _are_collinear(points, tol=None):
     points -= points.mean(axis=0)[np.newaxis, :]
     rank = matrix_rank(points, tol=tol)
     return rank == 1
+
+
+def _convert_polar_to_cartesian_coordinates(rho, phi):
+    # Adapted from https://stackoverflow.com/a/26757297/2912349
+    x = rho * np.cos(phi)
+    y = rho * np.sin(phi)
+    return(x, y)
